@@ -51,15 +51,15 @@ def allclose(a, b, rtol=1e-5, atol=1e-8, equal_nan=False):
         but not `array_equal`.
 
     Examples:
-        >>> x, y = numpoly.symbols("x y")
-        >>> numpoly.allclose([1e10*x, 1e-7], [1.00001e10*x, 1e-8])
+        >>> q0, q1 = numpoly.variable(2)
+        >>> numpoly.allclose([1e10*q0, 1e-7], [1.00001e10*q0, 1e-8])
         False
-        >>> numpoly.allclose([1e10*x, 1e-8], [1.00001e10*x, 1e-9])
+        >>> numpoly.allclose([1e10*q0, 1e-8], [1.00001e10*q0, 1e-9])
         True
-        >>> numpoly.allclose([1e10*x, 1e-8], [1.00001e10*y, 1e-9])
+        >>> numpoly.allclose([1e10*q0, 1e-8], [1.00001e10*q1, 1e-9])
         False
-        >>> numpoly.allclose([x, numpy.nan],
-        ...                  [x, numpy.nan], equal_nan=True)
+        >>> numpoly.allclose([q0, numpy.nan],
+        ...                  [q0, numpy.nan], equal_nan=True)
         True
 
     """
